@@ -7,7 +7,7 @@ use warnings;
 
 package App::Rssfilter::Logger;
 {
-  $App::Rssfilter::Logger::VERSION = '0.05';
+  $App::Rssfilter::Logger::VERSION = '0.06';
 }
 
 use Moo::Role;
@@ -25,13 +25,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Rssfilter::Logger - adds a logger to a class
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -52,8 +54,6 @@ C<App::Rssfilter::Logger> is a role that can be composed into any class, and add
 
 =head2 logger
 
-$receiver->logger->debug( 'cutting down trees' );
-
 This is a L<Log::Any> object.
 
 =head1 SEE ALSO
